==> tine20-allinone_2019.12.5.tar.bz2: Crm/js/Crm-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Client"

, "State"
: "Stat"

, "Role"
: "Rol"

, "Source"
: "Soursă"

, "Start"
: "Start"

, "Scheduled end"
: ""

, "End"
: "Final"

, "Turnover"
: "Cifra de afaceri"

, "Probability"
: "Probabilitate"

, "Folder"
: "Folder"

, "Updated by"
: "Actualizat de"

, "Updated Fields:"
: "Câmpuri actualizate:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Tags"
: "Taguri"

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Lead Data"
: ""

, "Leadstate"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "End Scheduled"
: "Final Programat"

, "Contacts"
: "Contacte"

, "Address"
: "Addresă"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "Tasks"
: "Taskuri"

, "Due Date"
: ""

, "Priority"
: "Prioritate"

, "Products"
: "Produse"

, "low"
: "scăzut"

, "normal"
: "normal"

, "high"
: "înalt"

, "urgent"
: "urgent"

, "All leads I have read grants for"
: ""

, "Last modified by me"
: "Ultima modificată de mine"

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification Emails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications Emails for own actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails to responsible"
: ""

, "Get notifications emails for action to responsible"
: ""

, "Send Notifications Emails to customer"
: ""

, "Get notifications emails for action to customer"
: ""

, "Send Notifications Emails to partner"
: ""

, "Get notifications emails for action to partner"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on crm startup"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Contact"
: "Contact"

, "CRM Role"
: "Rol CRM"

, "Lead, Leads"
: [
  ""
 ,""
 ,""

]
, "lead list, lead lists"
: [
  ""
 ,""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Lead name"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: "Creat de"

, "Estimated end"
: ""

, "Resubmission Date"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Partner"
: "Partener"

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Change type to Customer"
: "Schimbă tip la Client"

, "Responsible"
: "Responsabil"

, "Change type to Responsible"
: "Schimbă tip la Responsabil"

, "Change type to Partner"
: "Schimbă tip la Partener"

, "Change contact type"
: "Schimbă tip contact"

, "Search for Contacts to add ..."
: "Caută Contacte pentru adăugare ..."

, "Name"
: "Nume"

, "Data"
: "Data"

, "Cellphone"
: "Celular"

, "Add new {0}"
: "Adaugă Nou {0}"

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Editează {0}"

, "Edit selected {0}"
: "Editează selectat {0}"

, "No Tasks to display"
: "Niciun Task de afişat"

, "Summary"
: "Sumar"

, "Add a task..."
: "Adaugă un task..."

, "Percent"
: "Procent"

, "Organizer"
: "Organizează"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: "Selectează Rol"

, "Adding {0} contacts to lead"
: ""

, "Probable Turnover"
: ""

, "Import leads"
: ""

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "Descriere"

, "Enter description"
: ""

, "New Lead"
: ""

, "Product"
: "Produs"

, "Price"
: "Preţ"

, "Quantity"
: "Cantitate"

, "Search for Products to add ..."
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Task"
: "Task"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "deschis"

, "contacted"
: "contactat"

, "waiting for feedback"
: "în aşteptarea feadbackului"

, "quote sent"
: ""

, "accepted"
: "acceptat"

, "lost"
: "pierdut"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revânzător"

, "Enabled Features"
: ""

, "Enabled Features in Crm Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification email on lead import"
: ""

, "Sends an email to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-ro_RO-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Romanian (Romania) (http://www.transifex.com/tine20/tine20/language/ro_RO/)\nLanguage: ro_RO\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: ""

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: ""

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Favorite Implicit"

, "The default favorite which is loaded on crm startup"
: ""

, "New Lead"
: ""

, "Tags"
: "Taguri"

, "Lead name"
: ""

, "Responsible"
: "Responsabil"

, "Partner"
: "Partener"

, "Customer"
: "Client"

, "Leadstate"
: ""

, "Leadtype"
: ""

, "Leadsource"
: ""

, "Probability"
: "Probabilitate"

, "Turnover"
: "Cifra de afaceri"

, "Estimated end"
: ""

, "Probable Turnover"
: ""

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Contact"

, "CRM Role"
: "Rol CRM"

, "Tasks"
: "Taskuri"

, "No Tasks to display"
: "Niciun Task de afişat"

, "Summary"
: "Sumar"

, "Add a task..."
: "Adaugă un task..."

, "Due Date"
: ""

, "Priority"
: "Prioritate"

, "Percent"
: "Procent"

, "Status"
: "Status"

, "Organizer"
: "Organizează"

, "Add new {0}"
: "Adaugă Nou {0}"

, "Unlink {0}"
: ""

, "Unlink selected {0}"
: ""

, "Edit {0}"
: "Editează {0}"

, "Edit selected {0}"
: "Editează selectat {0}"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  ""
 ,""
 ,""

]
, "Select Lead"
: ""

, "Role"
: "Rol"

, "Select Role"
: "Selectează Rol"

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Telefon"

, "Mobile"
: "Mobil"

, "Fax"
: "Fax"

, "E-Mail"
: "E-Mail"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Start"

, "Change type to Customer"
: "Schimbă tip la Client"

, "Change type to Responsible"
: "Schimbă tip la Responsabil"

, "Change type to Partner"
: "Schimbă tip la Partener"

, "Change contact type"
: "Schimbă tip contact"

, "Search for Contacts to add ..."
: "Caută Contacte pentru adăugare ..."

, "Name"
: "Nume"

, "Address"
: "Addresă"

, "Data"
: "Data"

, "Cellphone"
: "Celular"

, "End"
: "Final"

, "You do not have the run right for the Tasks application or it is not activated."
: ""

, "Products"
: "Produse"

, "You do not have the run right for the Sales application or it is not activated."
: ""

, "Enter lead name"
: ""

, "Expected turnover"
: ""

, "Description"
: "Descriere"

, "Enter description"
: ""

, "lead list, lead lists"
: [
  ""
 ,""
 ,""

]
, "lead lists"
: ""

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: "Creat de"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produs"

, "Price"
: "Preţ"

, "Quantity"
: "Cantitate"

, "Search for Products to add ..."
: ""

, "All leads I have read grants for"
: ""

, "Last modified by me"
: "Ultima modificată de mine"

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "deschis"

, "contacted"
: "contactat"

, "waiting for feedback"
: "în aşteptarea feadbackului"

, "quote sent"
: ""

, "accepted"
: "acceptat"

, "lost"
: "pierdut"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revânzător"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Stat"

, "Source"
: "Soursă"

, "Scheduled end"
: ""

, "Folder"
: "Folder"

, "Updated by"
: "Actualizat de"

, "Updated Fields:"
: "Câmpuri actualizate:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: ""

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: "Task"

, "Lead Data"
: ""

, "End Scheduled"
: "Final Programat"

, "Contacts"
: "Contacte"

, "Telephone"
: "Telefon"

, "Email"
: "Email"

, "low"
: "scăzut"

, "normal"
: "normal"

, "high"
: "înalt"

, "urgent"
: "urgent"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: ""

, "Create new shared lead folders"
: ""

, "manage shared leads favorites"
: ""

, "Create or update shared leads favorites"
: ""

, "Lead"
: ""

, "lead list"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
